@@ -21,7 +21,7 @@ from algebraic_structures import CummutativeAddition, \
                                  CummutativeMultiplication, Power
 
 __all__ = [
-    CummutativeAddition,
-    CummutativeMultiplication,
-    Power
+    'CummutativeAddition',
+    'CummutativeMultiplication',
+    'Power'
 ]
\ No newline at end of file
